Foundation | Welcome

# Welcome to Foundation

### We’re stoked you want to try Foundation!

To get going, this file (index.html) includes some basic styles you can modify, play around with, or totally destroy to get going.

Once you've exhausted the fun in this document, you should check out:

Foundation Documentation
Everything you need to know about using the framework.

Foundation on Github
Latest code, issue reports, feature requests and more.

@foundationzurb
Ping us on Twitter if you have questions. If you build something with this we'd love to see it (and send you a totally boss sticker).

##### Here’s your basic grid:

This is a twelve column section in a row. Each of these includes a div.panel element so you can see where the columns are - it's not required at all for the grid.

Six columns

Six columns

Four columns

Four columns

Four columns

##### We bet you’ll need a form somewhere:

Input Label
Input Label
Input Label
Input Label
.com
Select Box
Choose Your Favorite Radio 1 Radio 2
Check these out Checkbox 1 Checkbox 2
Textarea Label

##### Try one of these buttons:

Simple Button
Radius Button
Round Button
Success Btn
Alert Btn
Secondary Btn

##### So many components, girl!

A whole kitchen sink of goodies comes with Foundation. Checkout the docs to see them all, along with details on making them your own.

Go to Foundation Docs